@@ -20,11 +20,11 @@
 #ifdef CFG_SECURE_DATA_PATH
 #include <sdp_basic.h>
 #endif
+#include <sys/stat.h>
 #include <signed_hdr.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/stat.h>
 #include <sys/types.h>
 #include <ta_arm_bti.h>
 #include <ta_concurrent.h>
@@ -303,19 +303,32 @@ static void xtest_tee_test_1001(ADBG_Case_t *c)
 
 	Do_ADBG_BeginSubCase(c, "Core self tests");
 
-	(void)ADBG_EXPECT_TEEC_SUCCESS(c, TEEC_InvokeCommand(
-		&session, PTA_INVOKE_TESTS_CMD_SELF_TESTS, NULL, &ret_orig));
+	res = TEEC_InvokeCommand(&session, PTA_INVOKE_TESTS_CMD_SELF_TESTS,
+				 NULL, &ret_orig);
+	ADBG_EXPECT_TEEC_SUCCESS(c, res);
 
 	Do_ADBG_EndSubCase(c, "Core self tests");
 
 	Do_ADBG_BeginSubCase(c, "Core dt_driver self tests");
 
-	(void)ADBG_EXPECT_TEEC_SUCCESS(c, TEEC_InvokeCommand(
-		&session, PTA_INVOKE_TESTS_CMD_DT_DRIVER_TESTS, NULL,
-		&ret_orig));
+	res = TEEC_InvokeCommand(&session, PTA_INVOKE_TESTS_CMD_DT_DRIVER_TESTS,
+				 NULL, &ret_orig);
+	ADBG_EXPECT_TEEC_SUCCESS(c, res);
 
 	Do_ADBG_EndSubCase(c, "Core dt_driver self tests");
 
+	Do_ADBG_BeginSubCase(c, "Core transfer list self tests");
+
+	res = TEEC_InvokeCommand(&session,
+				 PTA_INVOKE_TESTS_CMD_TRANSFER_LIST_TESTS, NULL,
+				 &ret_orig);
+	if (res == TEE_ERROR_NOT_SUPPORTED)
+		Do_ADBG_Log("Transfer List tests not supported, skipping");
+	else
+		ADBG_EXPECT_TEEC_SUCCESS(c, res);
+
+	Do_ADBG_EndSubCase(c, "Core transfer list self tests");
+
 	TEEC_CloseSession(&session);
 }
 ADBG_CASE_DEFINE(regression, 1001, xtest_tee_test_1001, "Core self tests");
@@ -3348,7 +3361,7 @@ static void xtest_tee_test_1040(ADBG_Case_t *c)
 	size_t nt = NUM_THREADS;
 	size_t n = 0;
 
-	Do_ADBG_BeginSubCase(c, "Concurent invoke with panic in TA");
+	Do_ADBG_BeginSubCase(c, "Concurrent invoke with panic in TA");
 	for (n = 0; n < nt; n++) {
 		if (!ADBG_EXPECT(c, 0, pthread_create(&arg[n].thr, NULL,
 						      test_1040_thread,
@@ -3359,7 +3372,7 @@ static void xtest_tee_test_1040(ADBG_Case_t *c)
 		ADBG_EXPECT(c, 0, pthread_join(arg[n].thr, NULL));
 		ADBG_EXPECT_TEEC_SUCCESS(c, arg[n].res);
 	}
-	Do_ADBG_EndSubCase(c, "Concurent invoke with panic in TA");
+	Do_ADBG_EndSubCase(c, "Concurrent invoke with panic in TA");
 }
 ADBG_CASE_DEFINE(regression, 1040, xtest_tee_test_1040,
 		 "Test panic in concurrent open/invoke/close session");
@@ -3372,6 +3385,7 @@ static void xtest_tee_test_1041(ADBG_Case_t *c)
 	uint32_t ret_orig = 0;
 	struct stat sb = { };
 	bool found = false;
+	int max_wait = 20;
 	int i = 0;
 
 	res = xtest_teec_open_session(&sess, &(const TEEC_UUID)TA_FTPM_UUID,
@@ -3388,11 +3402,12 @@ static void xtest_tee_test_1041(ADBG_Case_t *c)
 	 * (5 seconds) otherwise the test may fail if run immediately after
 	 * boot.
 	 */
-	for (i = 0; i < 5; i++) {
+	for (i = 0; i < max_wait; i++) {
 		if (stat(fname, &sb) == 0) {
 			found = true;
 			break;
 		}
+		Do_ADBG_Log("Waiting for TPM device %d / %d", i, max_wait);
 		sleep(1);
 	}
 	if (!ADBG_EXPECT_TRUE(c, found)) {
